@@ -29,37 +29,24 @@
 
 #include <libgnome/gnome-program.h>
 
-#include <bonobo/Bonobo.h>
-
 G_BEGIN_DECLS
 
-/*
- * Bonobo::ConfigDatabase for desktop-wide settings.
+/* This is where the user specific files are stored under $HOME
+ * (do not use these macros; use gnome_user_dir_get(); it's possible
+ * to override .gnome2 via environment variable and this is
+ * an important feature for environments that mix GNOME versions)
  */
-Bonobo_ConfigDatabase
-gnome_program_get_desktop_config_database (GnomeProgram *program);
+#define GNOME_DOT_GNOME		".gnome2/"
+#define GNOME_DOT_GNOME_PRIVATE	".gnome2_private/"
 
-#define GNOME_PARAM_DESKTOP_CONFIG_DATABASE "desktop-config-database"
-#define GNOME_PARAM_DESKTOP_CONFIG_MONIKER  "desktop-config-moniker"
+#define LIBGNOME_MODULE libgnome_module_info_get()
+const GnomeModuleInfo *libgnome_module_info_get (void) G_GNUC_CONST;
+#define GNOME_BONOBO_MODULE gnome_bonobo_module_info_get()
+const GnomeModuleInfo * gnome_bonobo_module_info_get (void) G_GNUC_CONST;
 
-/*
- * Bonobo::ConfigDatabase for per-application settings.
- */
-Bonobo_ConfigDatabase
-gnome_program_get_config_database (GnomeProgram *program);
-
-/*
- * Shortcut for gnome_program_get_config_database (gnome_program_get ()).
- */
-Bonobo_ConfigDatabase
-gnome_get_config_database (void);
-
-#define GNOME_PARAM_CONFIG_DATABASE "config-database"
-#define GNOME_PARAM_CONFIG_MONIKER  "config-moniker"
-
-extern GnomeModuleInfo gnome_bonobo_activation_module_info;
-extern GnomeModuleInfo gnome_vfs_module_info;
-extern GnomeModuleInfo libgnome_module_info;
+const char *gnome_user_dir_get (void) G_GNUC_CONST;
+const char *gnome_user_private_dir_get (void) G_GNUC_CONST;
+const char *gnome_user_accels_dir_get (void) G_GNUC_CONST;
 
 G_END_DECLS
 
